/**
 * delta_dress.h — Backward compatibility shim.
 *
 * All declarations have been consolidated into dress/dress.h.
 * This header exists so that existing code with
 *
 *   #include "dress/delta_dress.h"
 *
 * continues to compile without changes.
 */
#ifndef DELTA_DRESS_H
#define DELTA_DRESS_H

#include "dress/dress.h"

#endif /* DELTA_DRESS_H */
